gedidb.SpatialConsolidationPlanner
==================================

.. currentmodule:: gedidb

.. autoclass:: SpatialConsolidationPlanner

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SpatialConsolidationPlanner.__init__
      ~SpatialConsolidationPlanner.compute
   
   

   
   
   